@@ -1,4 +1,9 @@
 #! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+# depthcharge-tools depthchargectl remove subcommand
+# Copyright (C) 2020-2022 Alper Nebi Yasak <alpernebiyasak@gmail.com>
+# See COPYRIGHT and LICENSE files for full copyright information.
 
 import argparse
 import logging
@@ -122,6 +127,8 @@ class depthchargectl_remove(
 
         partitions = depthchargectl.list(
             root=self.root,
+            root_mountpoint=self.root_mountpoint,
+            boot_mountpoint=self.boot_mountpoint,
             config=self.config,
             board=self.board,
             tmpdir=self.tmpdir / "list",
@@ -184,6 +191,8 @@ class depthchargectl_remove(
                     partition=part,
                     bad=True,
                     root=self.root,
+                    root_mountpoint=self.root_mountpoint,
+                    boot_mountpoint=self.boot_mountpoint,
                     config=self.config,
                     board=self.board,
                     tmpdir=self.tmpdir / "bless",
@@ -226,13 +235,13 @@ class depthchargectl_remove(
         if error_disks:
             error_msg.append(
                 "Couldn't disable partitions for disks {}."
-                .format(error_disks)
+                .format(", ".join(str(d) for d in error_disks))
             )
 
         if error_parts:
             error_msg.append(
                 "Couldn't disable partitions {}."
-                .format(error_parts)
+                .format(", ".join(str(d) for d in error_parts))
             )
 
         if error_msg:
