@@ -1,4 +1,9 @@
 #! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+# depthcharge-tools depthchargectl write subcommand
+# Copyright (C) 2020-2022 Alper Nebi Yasak <alpernebiyasak@gmail.com>
+# See COPYRIGHT and LICENSE files for full copyright information.
 
 import argparse
 import logging
@@ -195,6 +200,8 @@ class depthchargectl_write(
                 image = depthchargectl.build_(
                     kernel_version=self.kernel_version,
                     root=self.root,
+                    root_mountpoint=self.root_mountpoint,
+                    boot_mountpoint=self.boot_mountpoint,
                     config=self.config,
                     board=self.board,
                     tmpdir=self.tmpdir / "build",
@@ -220,6 +227,8 @@ class depthchargectl_write(
                 min_size=image.stat().st_size,
                 allow_current=self.allow_current,
                 root=self.root,
+                root_mountpoint=self.root_mountpoint,
+                boot_mountpoint=self.boot_mountpoint,
                 config=self.config,
                 board=self.board,
                 tmpdir=self.tmpdir / "target",
@@ -270,6 +279,8 @@ class depthchargectl_write(
                     partition=target,
                     oneshot=True,
                     root=self.root,
+                    root_mountpoint=self.root_mountpoint,
+                    boot_mountpoint=self.boot_mountpoint,
                     config=self.config,
                     board=self.board,
                     tmpdir=self.tmpdir / "bless",
