@@ -1,4 +1,9 @@
 #! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+# depthcharge-tools argparse utilities
+# Copyright (C) 2020-2022 Alper Nebi Yasak <alpernebiyasak@gmail.com>
+# See COPYRIGHT and LICENSE files for full copyright information.
 
 import argparse
 import copy
@@ -854,6 +859,9 @@ class CommandMeta(type):
         if isinstance(retval, CommandExit):
             if raise_exit:
                 raise retval
+            elif retval.returncode != 0 and hasattr(instance, "_logger"):
+                instance._logger.warning(retval.message)
+                retval = retval.output
             else:
                 retval = retval.output
 
@@ -872,6 +880,9 @@ class CommandMeta(type):
         if isinstance(retval, CommandExit):
             if raise_exit:
                 raise retval
+            elif retval.returncode != 0 and hasattr(instance, "_logger"):
+                instance._logger.warning(retval.message)
+                retval = retval.output
             else:
                 retval = retval.output
 
@@ -904,9 +915,7 @@ class CommandMeta(type):
                 log_error(err.__cause__)
             logger.error(err, exc_info=is_debug_level)
 
-        try:
-            output = command(__raise_CommandExit=True, **kwargs)
-
+        def print_out(output):
             if inspect.isgenerator(output):
                 try:
                     while True:
@@ -914,18 +923,26 @@ class CommandMeta(type):
                 except StopIteration as err:
                     output = err.value
 
-            if output is not None:
+            elif isinstance(output, list):
+                print(*output, sep="\n")
+
+            elif isinstance(output, tuple):
+                print(*output, sep="\n")
+
+            elif output is not None:
                 print(output)
 
+        try:
+            output = command(__raise_CommandExit=True, **kwargs)
+            print_out(output)
+
         except CommandExit as exit:
             if exit.returncode != 0:
                 log_error(exit)
             else:
                 logger.warning(exit)
 
-            if exit.output is not None:
-                print(exit.output)
-
+            print_out(exit.output)
             sys.exit(exit.returncode)
 
         except Exception as err:
