@@ -1,4 +1,9 @@
 #! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+# depthcharge-tools platform utilities
+# Copyright (C) 2020-2022 Alper Nebi Yasak <alpernebiyasak@gmail.com>
+# See COPYRIGHT and LICENSE files for full copyright information.
 
 import collections
 import glob
@@ -79,7 +84,24 @@ def os_release(root=None):
     return os_release
 
 
-def kernel_cmdline():
+def kernel_cmdline(root=None):
+    cmdline = ""
+
+    if root is None:
+        root = "/"
+    root = Path(root).resolve()
+
+    cmdline_f = root / "etc" / "kernel" / "cmdline"
+    if not cmdline_f.exists():
+        cmdline_f = root / "usr" / "lib" / "kernel" / "cmdline"
+
+    if cmdline_f.exists():
+        cmdline = cmdline_f.read_text().rstrip("\n")
+
+    return shlex.split(cmdline)
+
+
+def proc_cmdline():
     cmdline = ""
 
     cmdline_f = Path("/proc/cmdline")
@@ -95,7 +117,7 @@ def is_cros_boot():
         return True
 
     # Chrome OS firmware injects this into the kernel cmdline.
-    if "cros_secure" in kernel_cmdline():
+    if "cros_secure" in proc_cmdline():
         return True
 
     return False
@@ -147,6 +169,7 @@ def vboot_keys(*keydirs, system=True, root=None):
 
         keydirs = (
             *keydirs,
+            root / "etc" / "depthcharge-tools",
             root / "usr" / "share" / "vboot" / "devkeys",
             root / "usr" / "local" / "share" / "vboot" / "devkeys",
         )
@@ -173,6 +196,37 @@ def vboot_keys(*keydirs, system=True, root=None):
     return None, None, None, None
 
 
+def cpu_microcode(boot=None):
+    microcode = []
+
+    for f in (
+        *boot.glob("amd-ucode.img"),
+        *boot.glob("amd-uc.img"),
+    ):
+        if f.is_file():
+            microcode.append(f)
+            break
+
+    for f in (
+        *boot.glob("intel-ucode.img"),
+        *boot.glob("intel-uc.img"),
+    ):
+        if f.is_file():
+            microcode.append(f)
+            break
+
+    if not microcode:
+        for f in (
+            *boot.glob("early_ucode.cpio"),
+            *boot.glob("microcode.cpio"),
+        ):
+            if f.is_file():
+                microcode.append(f)
+                break
+
+    return microcode
+
+
 def installed_kernels(root=None, boot=None):
     kernels = {}
     initrds = {}
